@@ -57,9 +57,16 @@ public:
         Bit256,
     };
 
-    enum class ProxyProtocol { HTTP, SOCKS };
+    enum class ProxyProtocol {
+        HTTP,
+        SOCKS
+    };
 
-    enum class GatewayTransportType { Auto, HTTP, RPC };
+    enum class GatewayTransportType {
+        Auto,
+        HTTP,
+        RPC
+    };
 
     explicit RdpHostPreferences(KConfigGroup configGroup, QObject *parent = nullptr);
     ~RdpHostPreferences() override;
