@@ -42,7 +42,6 @@ VncView::VncView(QWidget *parent, const QUrl &url, KConfigGroup configGroup)
     , m_buttonMask(0)
     , m_quitFlag(false)
     , m_firstPasswordTry(true)
-    , m_dontSendClipboard(false)
     , m_horizontalFactor(1.0)
     , m_verticalFactor(1.0)
     , m_wheelRemainderV(0)
@@ -71,9 +70,6 @@ VncView::VncView(QWidget *parent, const QUrl &url, KConfigGroup configGroup)
         setCursor(cursor);
     });
 
-    m_clipboard = QApplication::clipboard();
-    connect(m_clipboard, SIGNAL(dataChanged()), this, SLOT(clipboardDataChanged()));
-
 #ifndef QTONLY
     m_hostPreferences = new VncHostPreferences(configGroup, this);
 #else
@@ -87,18 +83,6 @@ VncView::~VncView()
         startQuitting();
 }
 
-bool VncView::eventFilter(QObject *obj, QEvent *event)
-{
-    if (m_viewOnly) {
-        if (event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease || event->type() == QEvent::MouseButtonDblClick
-            || event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonRelease || event->type() == QEvent::Wheel
-            || event->type() == QEvent::MouseMove)
-            return true;
-    }
-
-    return RemoteView::eventFilter(obj, event);
-}
-
 QSize VncView::framebufferSize()
 {
     return m_frame.size() / devicePixelRatioF();
@@ -431,11 +415,9 @@ void VncView::updateImage(int x, int y, int w, int h)
         }
         setAttribute(Qt::WA_StaticContents);
         setAttribute(Qt::WA_OpaquePaintEvent);
-        installEventFilter(this);
 
         setCursor(((m_localCursorState == CursorOn) || m_forceLocalCursor) ? localDefaultCursor() : Qt::BlankCursor);
 
-        setMouseTracking(true); // get mouse events even when there is no mousebutton pressed
         setFocusPolicy(Qt::WheelFocus);
         setStatus(Connected);
         Q_EMIT connected();
@@ -492,8 +474,6 @@ void VncView::setViewOnly(bool viewOnly)
 {
     RemoteView::setViewOnly(viewOnly);
 
-    m_dontSendClipboard = viewOnly;
-
     if (viewOnly)
         setCursor(Qt::ArrowCursor);
     else
@@ -537,10 +517,9 @@ void VncView::enableScaling(bool scale)
 
 void VncView::setCut(const QString &text)
 {
-    const bool saved_dontSendClipboard = m_dontSendClipboard;
-    m_dontSendClipboard = true;
-    m_clipboard->setText(text, QClipboard::Clipboard);
-    m_dontSendClipboard = saved_dontSendClipboard;
+    QMimeData *data = new QMimeData;
+    data->setText(text);
+    remoteClipboardChanged(data);
 }
 
 void VncView::paintEvent(QPaintEvent *event)
@@ -574,34 +553,7 @@ void VncView::resizeEvent(QResizeEvent *event)
     update();
 }
 
-bool VncView::event(QEvent *event)
-{
-    switch (event->type()) {
-    case QEvent::KeyPress:
-    case QEvent::KeyRelease:
-        // qCDebug(KRDC) << "keyEvent";
-        keyEventHandler(static_cast<QKeyEvent *>(event));
-        return true;
-        break;
-    case QEvent::MouseButtonDblClick:
-    case QEvent::MouseButtonPress:
-    case QEvent::MouseButtonRelease:
-    case QEvent::MouseMove:
-        // qCDebug(KRDC) << "mouseEvent";
-        mouseEventHandler(static_cast<QMouseEvent *>(event));
-        return true;
-        break;
-    case QEvent::Wheel:
-        // qCDebug(KRDC) << "wheelEvent";
-        wheelEventHandler(static_cast<QWheelEvent *>(event));
-        return true;
-        break;
-    default:
-        return RemoteView::event(event);
-    }
-}
-
-void VncView::mouseEventHandler(QMouseEvent *e)
+void VncView::handleMouseEvent(QMouseEvent *e)
 {
     if (e->type() != QEvent::MouseMove) {
         if ((e->type() == QEvent::MouseButtonPress) || (e->type() == QEvent::MouseButtonDblClick)) {
@@ -626,14 +578,14 @@ void VncView::mouseEventHandler(QMouseEvent *e)
     }
 
     const auto dpr = devicePixelRatioF();
-    QPointF screenPos = e->screenPos();
+    QPointF screenPos = e->globalPosition();
     // We need to restore mouse position in device coordinates.
     // QMouseEvent::localPos() can be rounded (bug in Qt), but QMouseEvent::screenPos() is not.
     QPointF pos = (e->pos() + (screenPos - screenPos.toPoint())) * dpr;
     vncThread.mouseEvent(qRound(pos.x() / m_horizontalFactor), qRound(pos.y() / m_verticalFactor), m_buttonMask);
 }
 
-void VncView::wheelEventHandler(QWheelEvent *event)
+void VncView::handleWheelEvent(QWheelEvent *event)
 {
     const auto delta = event->angleDelta();
     // Reset accumulation if direction changed
@@ -680,7 +632,7 @@ void VncView::saveWalletSshPassword()
 }
 #endif
 
-void VncView::keyEventHandler(QKeyEvent *e)
+void VncView::handleKeyEvent(QKeyEvent *e)
 {
     // strip away autorepeating KeyRelease; see bug #206598
     if (e->isAutoRepeat() && (e->type() == QEvent::KeyRelease))
@@ -696,63 +648,27 @@ void VncView::keyEventHandler(QKeyEvent *e)
     }
 
     const bool pressed = (e->type() == QEvent::KeyPress);
-
-    // handle modifiers
-    if (k == XK_Shift_L || k == XK_Control_L || k == XK_Meta_L || k == XK_Alt_L || XK_Super_L || XK_Hyper_L || k == XK_Shift_R || k == XK_Control_R
-        || k == XK_Meta_R || k == XK_Alt_R || XK_Super_R || XK_Hyper_R) {
-        if (pressed) {
-            m_mods[k] = true;
-        } else if (m_mods.contains(k)) {
-            m_mods.remove(k);
-        } else {
-            unpressModifiers();
-        }
-    }
-
     if (k) {
         vncThread.keyEvent(k, pressed);
     }
 }
 
-void VncView::unpressModifiers()
+void VncView::handleLocalClipboardChanged(const QMimeData *data)
 {
-    const QList<unsigned int> keys = m_mods.keys();
-    QList<unsigned int>::const_iterator it = keys.constBegin();
-    while (it != keys.end()) {
-        qCDebug(KRDC) << "VncView::unpressModifiers key=" << (*it);
-        vncThread.keyEvent(*it, false);
-        it++;
-    }
-    m_mods.clear();
-}
-
-void VncView::clipboardDataChanged()
-{
-    if (m_status != Connected)
-        return;
-
-    if (m_clipboard->ownsClipboard() || m_dontSendClipboard)
-        return;
 #ifndef QTONLY
     if (m_hostPreferences->dontCopyPasswords()) {
-        const QMimeData *data = m_clipboard->mimeData();
-        if (data && data->hasFormat(QLatin1String("x-kde-passwordManagerHint"))) {
+        if (data->hasFormat(QLatin1String("x-kde-passwordManagerHint"))) {
             qCDebug(KRDC) << "VncView::clipboardDataChanged data hasFormat x-kde-passwordManagerHint -- ignoring";
             return;
         }
     }
 #endif
-    const QString text = m_clipboard->text(QClipboard::Clipboard);
 
-    vncThread.clientCut(text);
-}
-
-void VncView::focusOutEvent(QFocusEvent *event)
-{
-    qCDebug(KRDC) << "VncView::focusOutEvent";
-    unpressModifiers();
-
-    RemoteView::focusOutEvent(event);
+    // TODO: VNC backend doesn't support other formats like  hasImage(), hasHtml()
+    if (data->hasText()) {
+        const QString text = data->text();
+        vncThread.clientCut(text);
+    }
 }
 
 #include "moc_vncview.cpp"
